@@ -8,11 +8,8 @@
  * @author Evert Pot (http://evertpot.com/)
  * @license http://sabre.io/license/ Modified BSD License
  */
-
-use
-    Sabre\HTTP\Request,
-    Sabre\HTTP\Client;
-
+use Sabre\HTTP\Request;
+use Sabre\HTTP\Client;
 
 // Find the autoloader
 $paths = [
@@ -22,7 +19,7 @@ $paths = [
 
 ];
 
-foreach($paths as $path) {
+foreach ($paths as $path) {
     if (file_exists($path)) {
         include $path;
         break;
